@@ -222,7 +222,7 @@ sfFgb = function(x,
     if (scalebar) list(position = "bottomleft")
     , if (homebutton) list(
       ext = createExtent(x)
-      , group = layer.name
+      , group = gsub("[[:punct:] ]", "_", layer.name)
       , position = mapviewGetOption("homebutton.pos")
     )
     , if (is.null(map)) list(
